@@ -30,7 +30,7 @@ class GPT3(object):
         }
         r = requests.post(self.endpoint_url,
             headers={
-                "api-key": self.apikey,
+                "Authorization": f"Bearer {self.apikey}",
                 "Content-Type": "application/json"
             },
             json = payload
